fix doxygen generation
[obnox/wireshark/wip.git] / print.h
diff --git a/print.h b/print.h
index 73f9116d38339229170a1562499a1a525b74f92d..a0871fb47b2060be9ba3fc3e4dbb831c7335c897 100644 (file)
--- a/print.h
+++ b/print.h
@@ -1,7 +1,7 @@
 /* print.h
  * Definitions for printing packet analysis trees.
  *
- * $Id: print.h,v 1.45 2004/07/08 10:36:27 guy Exp $
+ * $Id$
  *
  * Gilbert Ramirez <gram@alumni.rice.edu>
  *
 
 #include <epan/packet.h>
 
+#include "packet-range.h"
+
+/*
+ * Print stream code; this provides a "print stream" class with subclasses
+ * of various sorts.  Additional subclasses might be implemented elsewhere.
+ */
+struct print_stream;
+
+typedef struct print_stream_ops {
+       gboolean (*print_preamble)(struct print_stream *self, gchar *filename);
+       gboolean (*print_line)(struct print_stream *self, int indent,
+           const char *line);
+       gboolean (*print_bookmark)(struct print_stream *self,
+           const gchar *name, const gchar *title);
+       gboolean (*new_page)(struct print_stream *self);
+       gboolean (*print_finale)(struct print_stream *self);
+       gboolean (*destroy)(struct print_stream *self);
+} print_stream_ops_t;
+
+typedef struct print_stream {
+       const print_stream_ops_t *ops;
+       void *data;
+} print_stream_t;
+
+extern print_stream_t *print_stream_text_new(int to_file, const char *dest);
+extern print_stream_t *print_stream_text_stdio_new(FILE *fh);
+extern print_stream_t *print_stream_ps_new(int to_file, const char *dest);
+extern print_stream_t *print_stream_ps_stdio_new(FILE *fh);
+
+extern gboolean print_preamble(print_stream_t *self, gchar *filename);
+extern gboolean print_line(print_stream_t *self, int indent, const char *line);
+extern gboolean print_bookmark(print_stream_t *self, const gchar *name,
+    const gchar *title);
+extern gboolean new_page(print_stream_t *self);
+extern gboolean print_finale(print_stream_t *self);
+extern gboolean destroy_print_stream(print_stream_t *self);
+
 /* print output format */
 typedef enum {
   PR_FMT_TEXT,    /* plain text */
-  PR_FMT_PS,      /* postscript */
+  PR_FMT_PS       /* postscript */
 } print_format_e;
 
 /* print_range, enum which frames should be printed */
@@ -52,7 +89,8 @@ typedef enum {
 } print_dissections_e;
 
 typedef struct {
-  print_format_e    format;            /* plain text, PostScript, PDML, ... */
+  print_stream_t *stream;      /* the stream to which we're printing */
+  print_format_e format;       /* plain text or PostScript */
   gboolean     to_file;        /* TRUE if we're printing to a file */
   char         *file;          /* file output pathname */
   char         *cmd;           /* print command string (not win32) */
@@ -67,23 +105,20 @@ typedef struct {
                    before each new packet */
 } print_args_t;
 
-/* Functions in print.h */
+/*
+ * Higher-level packet-printing code.
+ */
+
+extern gboolean proto_tree_print(print_args_t *print_args, epan_dissect_t *edt,
+     print_stream_t *stream);
+extern gboolean print_hex_data(print_stream_t *stream, epan_dissect_t *edt);
 
-extern FILE *open_print_dest(int to_file, const char *dest);
-extern gboolean close_print_dest(int to_file, FILE *fh);
-extern void print_preamble(FILE *fh, print_format_e format, gchar *filename);
-extern void print_packet_header(FILE *fh, print_format_e format, guint32 number, gchar *summary);
-extern void print_formfeed(FILE *fh, print_format_e format);
-extern void print_finale(FILE *fh, print_format_e format);
-extern void proto_tree_print(print_args_t *print_args, epan_dissect_t *edt,
-     FILE *fh);
 extern void write_pdml_preamble(FILE *fh);
 extern void proto_tree_write_pdml(epan_dissect_t *edt, FILE *fh);
 extern void write_pdml_finale(FILE *fh);
+
 extern void write_psml_preamble(FILE *fh);
 extern void proto_tree_write_psml(epan_dissect_t *edt, FILE *fh);
 extern void write_psml_finale(FILE *fh);
-extern void print_hex_data(FILE *fh, print_format_e format, epan_dissect_t *edt);
-extern void print_line(FILE *fh, int indent, print_format_e format, char *line);
 
 #endif /* print.h */